<?php
/**
 * Add theme dashboard page
 */

add_action('admin_menu', 'glow_theme_info');
function glow_theme_info() {
    $theme_data = wp_get_theme();
    add_theme_page( sprintf( esc_html__( '%s Dashboard', 'glow' ), $theme_data->Name ), sprintf( esc_html__('%s Theme', 'glow'), $theme_data->Name), 'edit_theme_options', 'glow', 'glow_theme_info_page');
}

if ( ! function_exists( 'glow_admin_scripts' ) ) :
    /**
     * Enqueue scripts for admin page only: Theme info page
     */
    function glow_admin_scripts( $hook ) {
        if ( $hook === 'widgets.php' || $hook === 'appearance_page_glow'  ) {
            wp_enqueue_style('glow-admin-css', get_template_directory_uri() . '/css/admin.css');
        }
    }
endif;
add_action('admin_enqueue_scripts', 'glow_admin_scripts');


function glow_theme_info_page() {

    $theme_data = wp_get_theme();

    // Check for current viewing tab
    $tab = null;
    if ( isset( $_GET['tab'] ) ) {
        $tab = $_GET['tab'];
    } else {
        $tab = null;
    }

    ?>
    <div class="wrap about-wrap theme_info_wrapper">
        <h1><?php printf(esc_html__('Welcome to %1s - Version %2s', 'glow'), $theme_data->Name, $theme_data->Version ); ?></h1>
        <div class="about-text"><?php esc_html_e( 'Glow is a massage center, beauty spa salon parlor responsive WordPress theme built with Bootstrap and is fully responsive for all the screen sizes. It can be used for Beauty, Salon, barber, Spa, Fitness, Wellness, Health, Blogging, Business, Agency, Corporate, Hospital, Massage parlor, Medicals, Doctors, Clinic or any other types of site. Glow theme comes with built-in widgets and widgets positions, customizer, drop-down menus, sliders, testimonials.', 'glow' ); ?></div>
        <a target="_blank" href="<?php echo esc_url('https://famethemes.com/?utm_source=theme_dashboard_page&utm_medium=badge_link&utm_campaign=theme_admin'); ?>" class="famethemes-badge wp-badge"><span>FameThemes</span></a>
        <h2 class="nav-tab-wrapper">
            <a href="?page=glow" class="nav-tab<?php echo is_null($tab) ? ' nav-tab-active' : null; ?>"><?php echo $theme_data->Name; ?></a>
        </h2>

        <?php if ( is_null($tab) ) { ?>
            <div class="theme_info info-tab-content">
                <div class="theme_info_column clearfix">
                    <div class="theme_info_left">

                        <div class="theme_link">
                            <h3><?php esc_html_e( 'Theme Customizer', 'glow' ); ?></h3>
                            <p class="about"><?php printf(esc_html__('%s supports the Theme Customizer for all theme settings. Click "Customize" to start customize your site.', 'glow'), $theme_data->Name); ?></p>
                            <p>
                                <a href="<?php echo admin_url('customize.php'); ?>" class="button button-primary"><?php esc_html_e('Start Customize', 'glow'); ?></a>
                            </p>
                        </div>
                        <div class="theme_link">
                            <h3><?php esc_html_e( 'Theme Documentation', 'glow' ); ?></h3>
                            <p class="about"><?php printf(esc_html__('Need any help to setup and configure %s? Please have a look at our documentations instructions.', 'glow'), $theme_data->Name); ?></p>
                            <p>
                                <a href="<?php echo esc_url( 'http://docs.famethemes.com/article/105-glow-documentation' ); ?>" target="_blank" class="button button-secondary"><?php esc_html_e('Online Documentation', 'glow'); ?></a>
                            </p>
                        </div>
                    </div>

                    <div class="theme_info_right">
                        <img src="<?php echo get_template_directory_uri(); ?>/screenshot.png" alt="Theme Screenshot" />
                    </div>
                </div>
            </div>
        <?php } ?>

    </div> <!-- END .theme_info -->

    <?php
}
?>
